.. ryvencore documentation master file, created by
   sphinx-quickstart on Wed Nov 24 09:44:03 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

`ryvencore` |version|
=====================================

:ref:`genindex`

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   ryvencore
   setup_cython

Welcome to the :code:`ryvencore` documentation!

These docs are built directly from the ryvencore sources and automatically represent the latest version on the main
branch on GitHub. Only the modules that are considered API are documented here. You can also find some documentation
regarding this project in the `Ryven guide`_ and the
`ryvencore-qt docs`_, however both of these are significantly out of date with the latest ryvencore version
at the time of writing. Please consider contributing, PRs welcome. For questions use the
`issues`_ on GitHub.

`Link to GitHub repository`_

.. _issues: https://github.com/leon-thomm/ryvencore/issues
.. _ryvencore-qt docs: https://leon-thomm.github.io/ryvencore-qt/#/
.. _Ryven guide: https://ryven.org/guide#/
.. _Link to GitHub repository: https://github.com/leon-thomm/ryvencore